@@ -14,7 +14,7 @@ class Record:
     def to_dict(self):
         return {
             "primitive": self.primitive,
-            "complex": {k: v.to_dict() for k, v in self.complex.items()},
+            "complex": [(k, v.to_dict()) for k, v in self.complex.items()],
         }
 
 
@@ -42,3 +42,13 @@ class ExpRunData:
             "aggregated": self.aggregated.to_dict(),
             "individual": [v.to_dict() for k, v in self.individual.items()],
         }
+
+
+@dataclass
+class RecordWithComplexSize(Record):
+    n_complex: int = field(default=0)
+
+    def to_dict(self):
+        o = super().to_dict()
+        o["n_complex"] = self.n_complex
+        return o
